==> org.apache.sling.connection-timeout-agent-1.0.2-source-release.zip: org.apache.sling.connection-timeout-agent-1.0.2/src/test/java/org/apache/sling/cta/impl/MisbehavingServerControl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.cta.impl;

import java.time.Duration;

/**
 * Allows control of a local server
 *
 */
public interface MisbehavingServerControl {

    /**
     * Returns the port on which the local server is bound
     * 
     * @return the port
     */
    int getLocalPort();

    /**
     * Sets a new value for the handleDelay parameter
     * 
     * <p>This value reflects how long the HTTP handler will wait before handling the client request.</p>
     * 
     * <p>The value only takes effect for the current test method invocation and will be reset
     * for the next one.</p>
     * 
     * @param handleDelay the new duration
     */
    void setHandleDelay(Duration handleDelay);
}

==> org.apache.sling.connection-timeout-agent-1.0.4-source-release.zip: org.apache.sling.connection-timeout-agent-1.0.4/src/test/java/org/apache/sling/cta/impl/MisbehavingServerControl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.cta.impl;

import java.time.Duration;

/**
 * Allows control of a local server
 *
 */
public interface MisbehavingServerControl {

    /**
     * Returns the port on which the local server is bound
     * 
     * @return the port
     */
    int getLocalPort();

    /**
     * Sets a new value for the handleDelay parameter
     * 
     * <p>This value reflects how long the HTTP handler will wait before handling the client request.</p>
     * 
     * <p>The value only takes effect for the current test method invocation and will be reset
     * for the next one.</p>
     * 
     * @param handleDelay the new duration
     */
    void setHandleDelay(Duration handleDelay);
    
    /**
     * Returns the port on which a local server that does not answer to connections is bound
     * 
     * @return the port
     */
    int getConnectTimeoutLocalPort();
}
